@@ -88,15 +88,18 @@ def convert_py_float_to_cffi( x):
 #     pxcffi = ffi.cast( "double *", px.ctypes.data)
 #     return px, pxcffi
 
-
 def convert_py_int_to_cffi( x):
-    if x != None:
-        px = np.ascontiguousarray( np.intc( x))    
+    if isinstance( x, np.ndarray) or x != None:
+        if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False) or ( x.dtype != np.int32):
+            px = np.ascontiguousarray( x, dtype = 'int32')
+        else:
+            px = x
     else: 
         # handle None
-        px = np.array( 0)     
-    pxcffi = ffi.cast( "int *", px.ctypes.data)
+        px = np.array( 0)
+    pxcffi = ffi.cast( "double *", px.ctypes.data)
     return px, pxcffi
+
    
 # def convert_py_int_to_cffi( x):
 #     if x != None:
@@ -109,6 +112,8 @@ def convert_py_int_to_cffi( x):
 #         pxcffi = ffi.cast( "int *", 0)
 #     return px, pxcffi
 
+
+
 ###
 # Python wrapper classes 
 ###
